@@ -1,5 +1,6 @@
 """Command-line interface."""
 import functools
+import sys
 from typing import Any
 from typing import Callable
 from typing import cast
@@ -40,9 +41,12 @@ def gitp_config_check(func: F) -> F:
                 "Error: no config found, please run `gitp config init`.",
                 fg="red",
             )
+            sys.exit(3)
         else:
             value = func(*args, **kwargs)
             _echo_outputs(value)
+            if not bool(value):
+                sys.exit(4)
             return value
 
     return cast(F, wrapper)
@@ -59,7 +63,9 @@ def _echo_outputs(response: Union[res.ResponseFailure, res.ResponseSuccess]) ->
         success = cast(res.ResponseSuccess, response)
         click.secho(success.value)
     else:
-        click.secho(f"Error: {response.value['message']}", fg="red")
+        click.secho(
+            f"Error(s) found during execution:\n{response.value['message']}", fg="red"
+        )
 
 
 def _get_github_service(config: c.Config) -> ghs.GithubService:
@@ -77,7 +83,7 @@ def _get_github_service(config: c.Config) -> ghs.GithubService:
         response = res.ResponseFailure(
             res.ResponseTypes.SYSTEM_ERROR,
             (
-                "Unable to reach server. Please check you network and credentials and "
+                "Unable to reach server. Please check your network and credentials and "
                 "try again."
             ),
         )
@@ -115,7 +121,7 @@ def commit(args: Tuple[str]) -> Union[res.ResponseFailure, res.ResponseSuccess]:
     )
 
 
-@main.command("pull")
+@main.command("pull", context_settings={"ignore_unknown_options": True})
 @click.argument("args", nargs=-1)
 @gitp_config_check
 def pull(args: Tuple[str]) -> Union[res.ResponseFailure, res.ResponseSuccess]:
@@ -193,11 +199,14 @@ def config_init() -> None:
             CONFIG_MANAGER.config.github_access_token
         )
         response = ci.ConfigInitUseCase(CONFIG_MANAGER).execute(settings)
-        _echo_outputs(response)
         if bool(response):
+            success = cast(res.ResponseSuccess, response)
+            click.secho(success.value)
             break
-        elif response.type == res.ResponseTypes.SYSTEM_ERROR:
-            click.ClickException("")
+        else:
+            click.secho(f"Error: {response.value['message']}", fg="red")
+            if response.type == res.ResponseTypes.SYSTEM_ERROR:
+                click.ClickException("")
 
 
 @configure.command("repos")
@@ -243,18 +252,19 @@ def create_issues() -> Union[res.ResponseFailure, res.ResponseSuccess]:
 def close_issues() -> Union[res.ResponseFailure, res.ResponseSuccess]:
     """Batch close issues on GitHub."""
     github_service = _get_github_service(CONFIG_MANAGER.config)
-    issues_title_query = p.InquirerPrompter.close_issues(
-        CONFIG_MANAGER.config.github_selected_repos
+    list_object = "issue"
+    title_query = p.InquirerPrompter.close_objects(
+        CONFIG_MANAGER.config.github_selected_repos, list_object
     )
-    request_issues = il.build_issue_list_request(
+    list_request = il.build_list_request(
         filters={
-            "obj__eq": "issue",
+            "obj__eq": list_object,
             "state__eq": "open",
-            "title__contains": issues_title_query,
+            "title__contains": title_query,
         }
     )
     return ghcli.GhCloseIssueUseCase(CONFIG_MANAGER, github_service).execute(
-        request_issues
+        list_request
     )
 
 
@@ -266,7 +276,8 @@ def create_prs() -> Union[res.ResponseFailure, res.ResponseSuccess]:
     pr = p.InquirerPrompter.create_pull_requests(
         CONFIG_MANAGER.config.github_selected_repos
     )
-    request_issues = il.build_issue_list_request(
+    # list for linked issues
+    list_request = il.build_list_request(
         filters={
             "obj__eq": "issue",
             "state__eq": "open",
@@ -274,7 +285,28 @@ def create_prs() -> Union[res.ResponseFailure, res.ResponseSuccess]:
         }
     )
     return ghcp.GhCreatePrUseCase(CONFIG_MANAGER, github_service).execute(
-        pr, request_issues
+        pr, list_request
+    )
+
+
+@close.command("prs")
+@gitp_config_check
+def close_prs() -> Union[res.ResponseFailure, res.ResponseSuccess]:
+    """Batch close pull requests on GitHub."""
+    github_service = _get_github_service(CONFIG_MANAGER.config)
+    list_object = "pull request"
+    title_query = p.InquirerPrompter.close_objects(
+        CONFIG_MANAGER.config.github_selected_repos, list_object
+    )
+    list_request = il.build_list_request(
+        filters={
+            "obj__eq": list_object,
+            "state__eq": "open",
+            "title__contains": title_query,
+        }
+    )
+    return ghcli.GhCloseIssueUseCase(CONFIG_MANAGER, github_service).execute(
+        list_request
     )
 
 
