@@ -1,22 +1,14 @@
 """List issue on Github use case."""
 from typing import Union
 
-import git_portfolio.config_manager as cm
-import git_portfolio.github_service as ghs
 import git_portfolio.request_objects.issue_list as il
 import git_portfolio.responses as res
+import git_portfolio.use_cases.gh as gh
 
 
-class GhListIssueUseCase:
+class GhListIssueUseCase(gh.GhUseCase):
     """Github list issue use case."""
 
-    def __init__(
-        self, config_manager: cm.ConfigManager, github_service: ghs.GithubService
-    ) -> None:
-        """Initializer."""
-        self.config_manager = config_manager
-        self.github_service = github_service
-
     def execute(
         self,
         request: Union[il.IssueListValidRequest, il.IssueListInvalidRequest],
